@ECHO OFF

REM The path of the JMDB installation (normally the current directory
REM which is accessed using the '%CD%' variable).
REM In this normal case you can leave it as it is.
SET JMDB_INST_PATH=%CD%

REM The name of the database service to start before JMDB will be started
REM when the autoupdater is started.
REM Leave it blank/empty if nothing should be done.
REM 
REM Windows:
REM ========
REM To get the name of the service you need to look it up in the Windows
REM services dialog which you can open using the following steps:
REM 1.) Press the "Windows-Key" + "R" to get the open dialog.
REM 2.) Then enter "services.msc" into the dialog box and press ENTER.
REM 3.) Now the services dialog will show up where you scroll down to
REM     the database PostgreSQL..., MySQL... and so on.
REM 4.) The name is what you have to enter at the end of the key
REM      "SET DATABASE_SERVICE_NAME=".
REM
REM Note:
REM =====
REM Windows: You'll have to run the command line with extended ADMIN rights
REM          otherwise there will be an error message (Windows Vista, Win7, etc.).
REM          Example services: "postgresql-9.5", "postgresql-x64-9.5", etc.
REM          Uses: net start <DATABASE_SERVICE_NAME>
REM Linux..: Your account needs to have the right to start and stop services.
REM          Uses: service <DATABASE_SERVICE_NAME> start
REM
SET DATABASE_SERVICE_NAME=

REM ==========================================================
REM  The current list of available servers can be found here:
REM  http://www.imdb.com/interfaces
REM ==========================================================

REM ================================================
REM  IMDb LIST files 
REM  The main data format from 199x to end if 2017!
REM ================================================
REM The FTP-Server address including the path on the server (remote).
REM Choose one of the servers below by removing the comment.
REM By default the German FU-Berlin (Free University Berlin) is active.
REM 
SET IMDB_LIST_FILES_FTP_ADDRESS="ftp://ftp.fu-berlin.de/pub/misc/movies/database/frozendata"
REM
REM Old locations of the IMDb LIST files (until September 2017)
REM ===========================================================
REM SET IMDB_LIST_FILES_FTP_ADDRESS="ftp://ftp.fu-berlin.de/pub/misc/movies/database"
REM SET IMDB_LIST_FILES_FTP_ADDRESS="ftp://ftp.funet.fi/pub/mirrors/ftp.imdb.com/pub"
REM SET IMDB_LIST_FILES_FTP_ADDRESS="ftp://ftp.sunet.se/pub/tv+movies/imdb"


REM ================================================
REM  IMDb TSV files 
REM  The new data format starting end of June 2017!
REM  This only contains a very limited subset of
REM  data (2018-03-02).
REM ================================================
REM The HTTPS-Server was introduced after a lot of complaints regarding
REM the Amazon S3 service.
REM
SET IMDB_TSV_FILES_HTTPS_ADDRESS="https://datasets.imdbws.com"

REM The newly introduced file storage Amazon S3 server path (remote).
REM BEWARE:
REM =======
REM Downloading from this source requires an S3 login and you have to pay
REM for the data you download!
SET IMDB_AMAZON_S3_ADDRESS="s3://imdb-datasets/documents/v1/"

REM The subdirectory to load the data from. If not set it will be synchronized
REM with the FTP download date.
REM Once only the AMAZON S3 data store is available because the FTP-Servers
REM are no longer updated, the 'current' subdirectory will be used.
REM The line is currently commented below.
SET IMDB_AMAZON_S3_SUBDIR=
REM SET IMDB_AMAZON_S3_SUBDIR=current

REM The S3 user access key used to login to Amazon S3
SET IMDB_AMAZON_S3_USER_ACCESS_KEY=

REM The S3 user secret key used to login to Amazon S3
SET IMDB_AMAZON_S3_USER_SECRET_KEY=


REM Space separated list of the IMDb list files that have to be downloaded.
REM
REM Important:
REM ==========
REM All IMDb files you have selected in the JMDB setup dialog must be listed
REM here, otherwise JMDB complains about missing files or skips them.
SET IMDB_DATA_FILE_LIST=
SET IMDB_COMPLETE_DATA_FILE_LIST=actors.list.gz actresses.list.gz aka-names.list.gz aka-titles.list.gz alternate-versions.list.gz biographies.list.gz business.list.gz certificates.list.gz cinematographers.list.gz color-info.list.gz composers.list.gz costume-designers.list.gz countries.list.gz crazy-credits.list.gz directors.list.gz distributors.list.gz editors.list.gz genres.list.gz german-aka-titles.list.gz goofs.list.gz italian-aka-titles.list.gz keywords.list.gz language.list.gz literature.list.gz locations.list.gz miscellaneous-companies.list.gz miscellaneous.list.gz movie-links.list.gz movies.list.gz mpaa-ratings-reasons.list.gz plot.list.gz producers.list.gz production-companies.list.gz production-designers.list.gz quotes.list.gz ratings.list.gz release-dates.list.gz running-times.list.gz sound-mix.list.gz soundtracks.list.gz special-effects-companies.list.gz taglines.list.gz technical.list.gz trivia.list.gz writers.list.gz title.basics.tsv.gz title.akas.tsv.gz title.episode.tsv.gz title.ratings.tsv.gz name.basics.tsv.gz title.crew.tsv.gz title.principals.tsv.gz
SET JMDB_UNSUPPORTED_DATA_FILE_LIST=miscellaneous-companies.list.gz special-effects-companies.list.gz

REM The base folder where an additional subdirectory (.\YYYY-MM-DD) is 
REM created each week for the IMDb data.
REM
REM NOTE:
REM =====
REM To build a more flexible path because the data is on a USB drive and
REM the drive letter changes you can use "%~d0". This is the drive letter
REM plus colon (e.g. "C:") of the current location of this batch script.
SET IMDB_DATA_BASE_DIR=C:\Downloads\IMDb

REM ===============================================================
REM OPTIONAL: The base folder where the IMDb IDs files are located.
REM           Normally this is a sub-directory of ${IMDB_DATA_BASE_DIR}
REM           These files are not available to the public and not
REM           available from the IMDb (except maybe if you have a
REM           license).
SET IMDB_ID_BASE_DIR=%IMDB_DATA_BASE_DIR%\IMDb_IDs

REM The path to the directory where the INFO-ZIP UNZIP.EXE can be
REM found (only needed if you have access to the IMDB ID file). 
REM You can download ZIP.EXE/UNZIP.EXE for Windows here:
REM ftp://ftp.info-zip.org/pub/infozip/win32/
SET INFOZIP_INST_PATH=C:\TOOLS\INFO-ZIP
REM ===============================================================
