#!/bin/bash
##############################################
# Java Movie Database (JMDB) startup script. #
##############################################

#
# Initialize desktop file related variables.
#
function INIT_DESKTOP_VARIABLES {
    #
    # The filename of the JMDB (Linux) desktop file
    # to be used to start JMDB via desktop shortcut.
    #
    DESKTOP_FILE_LINUX=jmdb_linux.desktop

    #
    # The current users location for desktop files.
    # The global directory should be '/usr/share/applications'.
    #
    DESKTOP_FILE_TARGET_DIRECTORY_APPLICATIONS=~/.local/share/applications

    #
    # When the file should show up on the main Desktop it should show 
    # in the users personal Desktop directory here: '~/Desktop'
    #
    DESKTOP_FILE_TARGET_DIRECTORY_MAIN_DESKTOP=~/Desktop
}



#
# Create the 'jmdb_linux.desktop' file.
# If it is required to do this as administrator 'sudo ' needs to be added before the 'tee' command below.
#
function CREATE_DESKTOP_FILE_LINUX {
    echo "Creating the desktop file '${JMDB_SCRIPT_PATH}/${DESKTOP_FILE_LINUX}'..."
    echo "============================================"
    echo "[Desktop Entry]"                                   | tee    "${JMDB_SCRIPT_PATH}/${DESKTOP_FILE_LINUX}"
    echo "Type=Application"                                  | tee -a "${JMDB_SCRIPT_PATH}/${DESKTOP_FILE_LINUX}"
    echo "Categories=Application;AudioVideo"                 | tee -a "${JMDB_SCRIPT_PATH}/${DESKTOP_FILE_LINUX}"
    echo "Version=1.0"                                       | tee -a "${JMDB_SCRIPT_PATH}/${DESKTOP_FILE_LINUX}"
    echo "Name=Java Movie Database"                          | tee -a "${JMDB_SCRIPT_PATH}/${DESKTOP_FILE_LINUX}"
    echo "#Path=${JMDB_SCRIPT_PATH}"                         | tee -a "${JMDB_SCRIPT_PATH}/${DESKTOP_FILE_LINUX}"
    echo "Exec=${JMDB_SCRIPT_PATH}/startlinux.sh"            | tee -a "${JMDB_SCRIPT_PATH}/${DESKTOP_FILE_LINUX}"
    echo "Icon=${JMDB_SCRIPT_PATH}/graphics/jmdblinux.xpm"   | tee -a "${JMDB_SCRIPT_PATH}/${DESKTOP_FILE_LINUX}"
    echo "Terminal=false"                                    | tee -a "${JMDB_SCRIPT_PATH}/${DESKTOP_FILE_LINUX}"
    echo "StartupNotify=false"                               | tee -a "${JMDB_SCRIPT_PATH}/${DESKTOP_FILE_LINUX}"
    echo "Keywords=JMDB,Java Movie Database"                 | tee -a "${JMDB_SCRIPT_PATH}/${DESKTOP_FILE_LINUX}"
    echo "============================================"
    echo
}



#
# Check and create desktop start entries
#
function CREATE_DESKTOP_ENTRY_LINUX {
    #
    # Initialize the required desktop variables
    #
    INIT_DESKTOP_VARIABLES

    #
    # Create the desktop file based on the current installation directory
    #
    CREATE_DESKTOP_FILE_LINUX

    echo "Creating symbolic links if required (will be skipped if the symlinks exist)..."
    #
    # Check if personal application directory exists.
    # If not create it...
    #
    if [[ ! -d "${DESKTOP_FILE_TARGET_DIRECTORY_APPLICATIONS}" ]]; then
        mkdir -p "${DESKTOP_FILE_TARGET_DIRECTORY_APPLICATIONS}"
    else
        echo "Users applications directory '${DESKTOP_FILE_TARGET_DIRECTORY_APPLICATIONS}' exists."
    fi

    #
    # Create a symlink to the users personal 'applications' folder where it should show up
    # in the  'Audio/Video' section.
    #
    if [[ -d "${DESKTOP_FILE_TARGET_DIRECTORY_APPLICATIONS}" ]]; then
        if [[ ! -f "${DESKTOP_FILE_TARGET_DIRECTORY_APPLICATIONS}/${DESKTOP_FILE_LINUX}" ]]; then
            ln -s "${JMDB_SCRIPT_PATH}/${DESKTOP_FILE_LINUX}" "${DESKTOP_FILE_TARGET_DIRECTORY_APPLICATIONS}/${DESKTOP_FILE_LINUX}"
        else
            echo "Users applications symlink '${DESKTOP_FILE_TARGET_DIRECTORY_APPLICATIONS}/${DESKTOP_FILE_LINUX}' does already exist."
        fi
    else
        echo "Users applications directory '${DESKTOP_FILE_TARGET_DIRECTORY_APPLICATIONS}' not found."
    fi

    #
    # Check if personal Desktop directory exists.
    # If not create it...
    #
    if [[ ! -d "${DESKTOP_FILE_TARGET_DIRECTORY_MAIN_DESKTOP}" ]]; then
        mkdir -p "${DESKTOP_FILE_TARGET_DIRECTORY_MAIN_DESKTOP}"
    else
        echo "Users desktop directory '${DESKTOP_FILE_TARGET_DIRECTORY_MAIN_DESKTOP}' exists."
    fi

    #
    # Create desktop file on users personal Desktop to start the application.
    #
    if [[ -d "${DESKTOP_FILE_TARGET_DIRECTORY_MAIN_DESKTOP}" ]]; then
        if [[ ! -f "${DESKTOP_FILE_TARGET_DIRECTORY_MAIN_DESKTOP}/${DESKTOP_FILE_LINUX}" ]]; then
            ln -s "${DESKTOP_FILE_TARGET_DIRECTORY_APPLICATIONS}/${DESKTOP_FILE_LINUX}" "${DESKTOP_FILE_TARGET_DIRECTORY_MAIN_DESKTOP}/${DESKTOP_FILE_LINUX}"
        else
            echo "Users desktop symlink '${DESKTOP_FILE_TARGET_DIRECTORY_APPLICATIONS}/${DESKTOP_FILE_LINUX}' does already exist."
        fi
    else
        echo "Users desktop directory '${DESKTOP_FILE_TARGET_DIRECTORY_MAIN_DESKTOP}' not found."
    fi
    echo
}



#
# Remove desktop start entries
#
function REMOVE_DESKTOP_ENTRY_LINUX {
    #
    # Initialize the required desktop variables
    #
    INIT_DESKTOP_VARIABLES


    #
    # Remove a symlinkfrom the users personal 'applications' folder if it does exist
    # in the  'Audio/Video' section.
    #
    if [[ -d "${DESKTOP_FILE_TARGET_DIRECTORY_APPLICATIONS}" ]]; then
        if [[ -f "${DESKTOP_FILE_TARGET_DIRECTORY_APPLICATIONS}/${DESKTOP_FILE_LINUX}" ]]; then
            echo "Deleting users application symlink file '${DESKTOP_FILE_TARGET_DIRECTORY_APPLICATIONS}/${DESKTOP_FILE_LINUX}'..."
            rm "${DESKTOP_FILE_TARGET_DIRECTORY_APPLICATIONS}/${DESKTOP_FILE_LINUX}"
        else
            echo "Users applications symlink '${DESKTOP_FILE_TARGET_DIRECTORY_APPLICATIONS}/${DESKTOP_FILE_LINUX}' did not exist."
        fi
    else
        echo "Users applications directory '${DESKTOP_FILE_TARGET_DIRECTORY_APPLICATIONS}' not found."
    fi


    #
    # Remove desktop file on users personal Desktop to start the application.
    #
    if [[ -d "${DESKTOP_FILE_TARGET_DIRECTORY_MAIN_DESKTOP}" ]]; then
        if [[ -f "${DESKTOP_FILE_TARGET_DIRECTORY_MAIN_DESKTOP}/${DESKTOP_FILE_LINUX}" ]]; then
            echo "Deleting users desktop symlink file '${DESKTOP_FILE_TARGET_DIRECTORY_MAIN_DESKTOP}/${DESKTOP_FILE_LINUX}'..."
            rm "${DESKTOP_FILE_TARGET_DIRECTORY_MAIN_DESKTOP}/${DESKTOP_FILE_LINUX}"
        else
            echo "Users desktop symlink '${DESKTOP_FILE_TARGET_DIRECTORY_APPLICATIONS}/${DESKTOP_FILE_LINUX}' did not exist."
        fi
    else
        echo "Users desktop directory '${DESKTOP_FILE_TARGET_DIRECTORY_MAIN_DESKTOP}' not found."
    fi
    echo
    echo "Exiting application now..."
    echo

    exit 0
}



#
# A simple pause function.
#
function PAUSE {
   read -p "Press [Enter] key to continue..."
}



#
# Get the location of this script (when called from some other directory).
#
JMDB_SCRIPT_PATH="$( cd "$( dirname $(readlink -f "${BASH_SOURCE[0]}") )" && pwd -P )"


#
# Change the current path to the location of this script.
#
cd "${JMDB_SCRIPT_PATH}"


#
# The number of parameters
#
echo "Number of parameters: ${#}"


#
# Set the import path.
#
IMDB_IMPORT_PATH=${1}


#
# Check if the variable actually contains a path and if not remove the value from the variable.
#
if [[ ! -d "${IMDB_IMPORT_PATH}" ]]; then
    IMDB_IMPORT_PATH=
fi


#
# Check number of parameters and if > 0 check all of them
#
if [[ (${#} -gt 0) ]]; then
    #
    # Process all parameters and check if one contains '--create_desktop_icons'.
    # If that is the case then create the desktop icons (desktop shortcut plus entry in applications list).
    #
    for PARAMETER in ${@:1}
    do
        #
        # Create Linux desktop shortcut (in users applications directory and directly on the desktop).
        #
        if [[ "${PARAMETER,,}" =~ ^--create-desktop-icons$ ]]; then
            echo
            echo "Parameter to create desktop icons found: ${PARAMETER}"
            echo "Creating desktop shortcuts..."
            echo
            CREATE_DESKTOP_ENTRY_LINUX
        fi

        #
        # Remove Linux desktop shortcut (in users applications directory and directly on the desktop).
        #
        if [[ "${PARAMETER,,}" =~ ^--remove-desktop-icons$ ]]; then
            echo
            echo "Parameter to remove desktop icons found: ${PARAMETER}"
            echo "Removing desktop shortcuts..."
            echo
            REMOVE_DESKTOP_ENTRY_LINUX
        fi
    done
fi


#
# Start JMDB depending on the state of the ${IMDB_IMPORT_PATH}.
#
if [ "x${IMDB_IMPORT_PATH}" == "x" ]; then
    # No parameter
    java -Xmx1600M -classpath .:jmdb.jar:postgresql-42.2.4.jre6.jar:jtds-1.3.1.jar:mysql-connector-java-5.1.46.jar:./plugins/export/itext-1.4.3.jar jmdb.base.JMDBMain
else
    # Start with parameter (IMDB_IMPORT_PATH)
    echo "Using IMDb import path ${IMDB_IMPORT_PATH}"
    java -Xmx1600M -classpath .:jmdb.jar:postgresql-42.2.4.jre6.jar:jtds-1.3.1.jar:mysql-connector-java-5.1.46.jar:./plugins/export/itext-1.4.3.jar jmdb.base.JMDBMain importpath="${IMDB_IMPORT_PATH}" importwithindex
fi
