@ECHO OFF
SETLOCAL EnableDelayedExpansion
GOTO INITVARS



:INITVARS
    ECHO Init variables...
    CALL JMDBEnvironment.cmd

    REM Initialisation of a helper variable to check if the data is
    REM complete (the value is modified and checked later..after
    REM the download step is complete).
    SET IMDB_DATA_COMPLETE=0
    
    REM A file to write the error messages to.
    SET GLOBAL_ERROR_FILE=%JMDB_INST_PATH%\startwinautoupdater_ERROR.log
    
    REM Set IMDb file date to fetch (will be automatically set later).
    SET IMDB_FETCH_DATE=
    
    ECHO Save old PATH environment
    SET OLDPATH=%PATH%
    
    ECHO Set new PATH environment
    SET PATH=%JMDB_INST_PATH%;%INFOZIP_INST_PATH%;%PATH%
    
    ECHO.
GOTO MAIN



:MAIN
    REM Check if the IMDb base directory exists.
    REM Create it if required.
    IF NOT EXIST "%IMDB_DATA_BASE_DIR%\" (
        MD "%IMDB_DATA_BASE_DIR%"
    )

    REM Get and check the date of the current movies.list.gz file
    REM on the FTP-Server
    ECHO "Checking movies.list.gz on FTP-Server..."
    @curl -v -X "NLST movies.list.gz" -Q "-MDTM movies.list.gz" "%IMDB_LIST_FILES_FTP_ADDRESS%/" 2>"%IMDB_DATA_BASE_DIR%\ftp_directory_listing.lst"

    REM
    REM Search for the date in the ftp_directory_listing.lst file (Pattern: "^\ 213\ [0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9]")
    REM ===========================
    REM   > MDTM movies.list.gz
    REM   < 213 20121109132726
    REM ===========================
    ECHO "Checking content of '%IMDB_DATA_BASE_DIR%\ftp_directory_listing.lst' for the date..."
    FOR /F "delims=" %%a IN ('findstr /R "^\ 213\ [0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9]" "%IMDB_DATA_BASE_DIR%\ftp_directory_listing.lst"') DO (
        SET MOD_DATE=%%a
    )
    REM end for

    REM
    REM Check the fetched result.
    REM
    IF "!MOD_DATE:~0,6!" EQU "< 213 " (
        REM Convert the line with the date as fetched
        REM into an ISO-8601 date format.
        SET IMDB_FETCH_DATE=!MOD_DATE:~6,4!-!MOD_DATE:~10,2!-!MOD_DATE:~12,2!
        ECHO IMDB_FETCH_DATE is set to... !IMDB_FETCH_DATE!
    ) ELSE (
        GOTO RESETVARS
    )
   
    ECHO "Calling IMDB_DATA_DOWNLOADER function..."
    CALL:IMDB_DATA_DOWNLOADER
    
    REM ECHO "Calling IMDB_S3_TSV_DATA_DOWNLOADER function..."
    REM CALL:IMDB_S3_TSV_DATA_DOWNLOADER
    
    ECHO "Calling IMDB_ID_EXTRACT function..."
    CALL:IMDB_ID_EXTRACT

    REM
    REM Go through the list of given IMDb files and check if
    REM they have been downloaded.
    REM
    FOR %%F IN (%IMDB_DATA_FILE_LIST%) DO (
        IF NOT EXIST "%IMDB_DATA_BASE_DIR%\!IMDB_FETCH_DATE!\%%F" (
           SET /A IMDB_DATA_COMPLETE=!IMDB_DATA_COMPLETE!-1
        )
        REM end if
    )
    REM end for (checking files)

    REM
    REM IF IMDB_DATA_COMPLETE == 0 then all files are there and we
    REM can call the [optional] service and finally run JMDB...
    REM
    IF %IMDB_DATA_COMPLETE% EQU 0 (
        REM ==================================================
        REM Start the database service using the given name...
        REM ==================================================
        IF "%DATABASE_SERVICE_NAME%" NEQ "" (
            NET START "%DATABASE_SERVICE_NAME%"
        )

        REM =============
        REM Start JMDB...
        REM =============
        ECHO "Starting normal JMDB startup script with necessary parameters..."
        startwindebug.cmd %IMDB_DATA_BASE_DIR%\!IMDB_FETCH_DATE!
    ) ELSE (
        ECHO "Files are incomplete...exiting now..."
        ECHO.
        EXIT %IMDB_DATA_COMPLETE%
    )
    REM end if
GOTO RESETVARS



:IMDB_DATA_DOWNLOADER
    REM ===================================================
    REM Check the JMDB.cfg files for deselected list files.
    REM ===================================================
    CALL:JMDB_CFG_IMDB_FILES

    REM Replace the ';' with '.list.gz ' (Note the SPACE at the end)
    REM and then append the files unsupported by JMDB.
    SET JMDB_SKIP_FILE_LIST=%JMDB_SKIP_FILE_LIST:;=.list.gz %
    SET JMDB_SKIP_FILE_LIST=%JMDB_SKIP_FILE_LIST%%JMDB_UNSUPPORTED_DATA_FILE_LIST%

    REM Initialize parameter to check if the files can be skipped
    REM or not.
    SET FOUND_JMDB_SKIP_FILE=0

    REM ==============================================
    REM Loop to generate the list of files to download
    REM by checking different file lists.
    REM ==============================================
    FOR %%K IN (%IMDB_COMPLETE_DATA_FILE_LIST%) DO (
        SET FOUND_JMDB_SKIP_FILE=0

        REM ====================================
        REM Inner look checking which files have
        REM to be skipped.
        REM ====================================
        FOR %%J IN (%JMDB_SKIP_FILE_LIST%) DO (
            IF "%%K" EQU "%%J" (
                SET FOUND_JMDB_SKIP_FILE=1
            )
            REM end if
        )
        REM end for

        REM =====================================================
        REM Add file to download list if FOUND_JMDB_SKIP_FILE==0.
        REM =====================================================
        IF !FOUND_JMDB_SKIP_FILE! EQU 0 (
           SET IMDB_DATA_FILE_LIST=!IMDB_DATA_FILE_LIST! %%K
        )
        REM end if
    )
    REM end for

    ECHO "About to download these files: %IMDB_DATA_FILE_LIST%"

    REM Check if the IMDb base directory including the subdirectory with the release date
    REM for the current movie.list.gz file exists.
    REM Create it if required.
    IF NOT EXIST "%IMDB_DATA_BASE_DIR%\%IMDB_FETCH_DATE%\" (
        MD "%IMDB_DATA_BASE_DIR%\%IMDB_FETCH_DATE%"
    )
    REM end if not exist (target directory)

    REM Go through the list of given IMDb files and download each of
    REM them (the downloader tries it multiple times if required).
    FOR %%F IN (%IMDB_DATA_FILE_LIST%) DO (
        ECHO "Downloading %%F..."
        REM wget --continue --tries=5 --wait=5 --timestamping --directory-prefix="%IMDB_DATA_BASE_DIR%\%IMDB_FETCH_DATE%" "%IMDB_LIST_FILES_FTP_ADDRESS%/%%F"
        curl -C - --retry 5 --retry-delay 5 --progress-bar --remote-time --output "%IMDB_DATA_BASE_DIR%\%IMDB_FETCH_DATE%\%%F" "%IMDB_LIST_FILES_FTP_ADDRESS%/%%F"
        ECHO.
        ECHO.
    )
    REM end for (each space separated entry (=one IMDb list file) will be downloaded by wget with retries and a pause between those)
    
    REM ECHO "IMDB_DATA_COMPLETE status after downloading files: " %IMDB_DATA_COMPLETE%
GOTO:EOF



:IMDB_S3_TSV_DATA_DOWNLOADER
    REM Check if the IMDb base directory including the subdirectory with the release date
    REM for the current movie.list.gz file exists.
    REM Create it if required.
    IF NOT EXIST "%IMDB_DATA_BASE_DIR%\%IMDB_FETCH_DATE%\" (
        MD "%IMDB_DATA_BASE_DIR%\%IMDB_FETCH_DATE%"
    )
    
    IF "%IMDB_AMAZON_S3_SUBDIR%x"=="x" (
        SET IMDB_AMAZON_S3_SUBDIR=%IMDB_FETCH_DATE%
    )
    
    REM Configure the 'imdb_s3_profile' profile using AMAZON AWS configure...
    aws configure set aws_access_key_id %IMDB_AMAZON_S3_USER_ACCESS_KEY% --profile imdb_s3_profile
    aws configure set aws_secret_access_key %IMDB_AMAZON_S3_USER_SECRET_KEY% --profile imdb_s3_profile
    REM aws configure set default.region none --profile imdb_s3_profile
    
    REM Enable the default profile only used to download the IMDb files from the Amazon S3 service.
    SET AWS_DEFAULT_PROFILE=imdb_s3_profile
    
    REM Login to Amazon S3 and copy (download) data from the S3 'bucket' directory to the local directory.
    aws s3 cp "%IMDB_AMAZON_S3_ADDRESS%/%IMDB_AMAZON_S3_SUBDIR%/" "%IMDB_DATA_BASE_DIR%\%IMDB_FETCH_DATE%" --recursive --request-payer requester
GOTO:EOF



:IMDB_ID_EXTRACT
    FOR /F %%F IN ('DIR "%IMDB_ID_BASE_DIR%\movies_imdbid_????-??-??.zip" /A-D /O-N /B') DO (
        IF NOT EXIST "%IMDB_DATA_BASE_DIR%\%IMDB_FETCH_DATE%\movies_imdbid.list" (
            ECHO "Found %%F...extracting..."
            Call unzip -n "%IMDB_ID_BASE_DIR%\%%F" -d "%IMDB_DATA_BASE_DIR%\%IMDB_FETCH_DATE%"
        )
        REM end if..else..
   )
   REM end for (look for the latest movie IMDb-ID file on the file system)
   ECHO.
GOTO:EOF



:JMDB_CFG_IMDB_FILES
    FOR /F "delims== tokens=2" %%i IN ('findstr /C:"JMDBMain.cfgDeselectedImportFiles=" "%JMDB_INST_PATH%\jmdb.cfg"') DO (
        SET JMDB_SKIP_FILE_LIST=%%i
    )
    REM end for
GOTO:EOF



:RESETVARS
    ECHO Restore old PATH environment
    SET PATH=%OLDPATH%
    SET INFOZIP_INST_PATH=
    SET JMDB_INST_PATH=
    SET IMDB_LIST_FILES_FTP_ADDRESS=
    SET IMDB_DATA_BASE_DIR=
    SET IMDB_DATA_FILE_LIST=
    SET IMDB_DATA_COMPLETE=0
    SET IMDB_ID_BASE_DIR=
    SET IMDB_FETCH_DATE=
    SET MOD_DATE=
    SET JMDB_SKIP_FILE_LIST=
    SET FOUND_JMDB_SKIP_FILE=
    ENDLOCAL
    ECHO.
GOTO ENDSCRIPT



:ENDSCRIPT
ECHO.
ECHO ==========
ECHO The End...
ECHO ==========
ECHO.